@@ -27,6 +27,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 
@@ -956,23 +957,15 @@ void save_greeter_settings (void)
 
 void save_qt_settings (void)
 {
-    char *user_config_file, *str;
+    char *user_config_file, *str, *cstrb, *cstrf;
     GKeyFile *kf;
     gsize len;
     char buffer[100], tbuf[400], *c;
     const char *font;
-    int size, weight, style, nlen, count, index, oind;
+    int size, weight, style, nlen, count, index, oind, dark;
     double sval;
 
-    // construct the file path
-    user_config_file = g_build_filename (g_get_user_config_dir (), "qt5ct/qt5ct.conf", NULL);
-    check_directory (user_config_file);
-
-    // read in data from file to a key file
-    kf = g_key_file_new ();
-    g_key_file_load_from_file (kf, user_config_file, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, NULL);
-
-    // create the Qt font representation
+    // parse the font description
     PangoFontDescription *pfd = pango_font_description_from_string (cur_conf.desktop_font);
     font = pango_font_description_get_family (pfd);
     size = pango_font_description_get_size (pfd) / (pango_font_description_get_size_is_absolute (pfd) ? 1 : PANGO_SCALE);
@@ -1012,6 +1005,7 @@ void save_qt_settings (void)
                                     break;
     }
 
+    // create the Qt font representation
     memset (buffer, 0, sizeof (buffer));
 
     // header
@@ -1100,18 +1094,61 @@ void save_qt_settings (void)
     tbuf[oind++] = '"';
     tbuf[oind] = 0;
 
-    // update changed values in the key file
-    g_key_file_set_value (kf, "Fonts", "fixed", tbuf);
-    g_key_file_set_value (kf, "Fonts", "general", tbuf);
-
-    // write the modified key file out
-    str = g_key_file_to_data (kf, &len, NULL);
-    g_file_set_contents (user_config_file, str, len, NULL);
-
     pango_font_description_free (pfd);
-    g_free (str);
-    g_key_file_free (kf);
-    g_free (user_config_file);
+
+    // write files for Qt5 (index = 0) and Qt6 (1)
+    for (index = 0; index < 2; index++)
+    {
+        // construct the file path
+        user_config_file = g_build_filename (g_get_user_config_dir (), index ? "qt6ct/qt6ct.conf" : "qt5ct/qt5ct.conf", NULL);
+        check_directory (user_config_file);
+        if (index)
+        {
+            str = g_build_filename (g_get_user_config_dir (), "qt6ct/colors/", NULL);
+            g_mkdir_with_parents (str, S_IRUSR | S_IWUSR | S_IXUSR);
+            vsystem ("cp /etc/xdg/qt6ct/colors/* %s/qt6ct/colors/", g_get_user_config_dir ());
+            g_free (str);
+        }
+
+        // read in data from file to a key file - read system defaults first for Qt6, as they aren't inherited...
+        kf = g_key_file_new ();
+        if (index) g_key_file_load_from_file (kf, "/etc/xdg/qt6ct/qt6ct.conf", G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, NULL);
+        g_key_file_load_from_file (kf, user_config_file, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, NULL);
+
+        // update changed values in the key file
+        g_key_file_set_value (kf, "Fonts", "fixed", tbuf);
+        g_key_file_set_value (kf, "Fonts", "general", tbuf);
+
+        if (index)
+        {
+            g_key_file_set_value (kf, "Appearance", "color_scheme_path",
+                cur_conf.darkmode ? "~/.config/qt6ct/colors/pixonyx.conf" : "~/.config/qt6ct/colors/pixtrix.conf");
+            g_key_file_set_value (kf, "Appearance", "custom_palette", "true");
+
+            for (dark = 0; dark < 2; dark++)
+            {
+                cstrb = rgba_to_gdk_color_string (&cur_conf.theme_colour[dark]);
+                cstrf = rgba_to_gdk_color_string (&cur_conf.themetext_colour[dark]);
+
+                vsystem ("sed -i 's/#ff%s, #ff%s,/#ff%s, #ff%s,/g' %s/qt6ct/colors/pix%s.conf",
+                    dark ? "76747c" : "87919b", dark ? "f6f5f4" : "f0f0f0", cstrb + 1, cstrf + 1,
+                    g_get_user_config_dir (), dark ? "onyx" : "trix");
+                vsystem ("sed -i 's/#ff%s$/#ff%s/g' %s/qt6ct/colors/pix%s.conf",
+                    dark ? "76747c" : "87919b", cstrb + 1, g_get_user_config_dir (), dark ? "onyx" : "trix");
+
+                g_free (cstrb);
+                g_free (cstrf);
+            }
+        }
+
+        // write the modified key file out
+        str = g_key_file_to_data (kf, &len, NULL);
+        g_file_set_contents (user_config_file, str, len, NULL);
+        g_free (user_config_file);
+
+        g_free (str);
+        g_key_file_free (kf);
+    }
 }
 
 void save_app_settings (void)
@@ -1229,6 +1266,7 @@ static void on_theme_colour_set (GtkColorChooser *btn, gpointer ptr)
 
     save_session_settings ();
     save_gtk3_settings ();
+    save_qt_settings ();
 
     reload_session ();
     reload_theme (FALSE);
@@ -1240,6 +1278,7 @@ static void on_theme_textcolour_set (GtkColorChooser *btn, gpointer ptr)
 
     save_session_settings ();
     save_gtk3_settings ();
+    save_qt_settings ();
 
     reload_session ();
     reload_theme (FALSE);
@@ -1308,6 +1347,7 @@ static void on_theme_dark_set (GtkRadioButton *btn, gpointer ptr)
 
     save_session_settings ();
     save_gtk3_settings ();
+    save_qt_settings ();
     save_app_settings ();
     save_greeter_settings ();
 
